@@ -323,7 +323,7 @@ class Blocks(EventDispatcher):
 		# w = Blocks.getWidgetById(desc.get('wid','self'),from_widget=widget)
 		w = Blocks.findWidget(desc.get('wid','self'),from_widget=widget)
 		if not w:
-			Logger.info('Block: %s %s',desc.get('wid','self'),
+			Logger.info('Block: id(%s) %s',desc.get('wid','self'),
 							'not found via Blocks.getWidgetById()')
 			return
 		event = desc.get('event')
@@ -431,8 +431,11 @@ class Blocks(EventDispatcher):
 	def urlwidgetAction(self, widget:Widget, desc, *args):
 		target = self.get_target(widget, desc)
 		add_mode = desc.get('mode','replace')
-		opts = desc.get('options').copy()
-		p = opts.get('params',{}).copy()
+		opts = desc.get('options', {}).copy()
+		p1 = opts.get('params',{})
+		p = {}
+		if p1:
+			p.update(p1)
 		if len(args) >= 1 and isinstance(args[0],dict):
 			p.update(args[0])
 		d = self.getActionData(widget, desc, *args)
@@ -716,15 +719,20 @@ class Blocks(EventDispatcher):
 				children = [i for i in from_widget.children]
 				if hasattr(from_widget, 'get_subwidgets'):
 					children = from_widget.get_subwidgets()
+				Logger.info('children=%s', str(children))
 				for c in children:
-					ret = find_func(id,from_widget=c)
+					ret = _find_widget(name, from_widget=c, dir=dir)
 					if ret:
 						return ret
 			else:
 				if isinstance(from_widget, WindowBase):
 					return None
 				if from_widget.parent:
-					return find_func(id, from_widget=from_widget.parent)
+					return _find_widget(name, 
+								from_widget=from_widget.parent,
+								dir=dir)
+			Logger.info('Block:_find_widget(), %s, %s %s return None',
+						name, from_widget.__class__.__name__, dir)
 			return None
 
 		def find_widget(step, from_widget):
@@ -734,6 +742,7 @@ class Blocks(EventDispatcher):
 				step = step[1:]
 			find_func = find_widget_by_id
 			if step[0:1] == '@':
+				step = step[1:]
 				find_func = find_widget_by_class
 			return _find_widget(step, from_widget=from_widget, 
 						dir=dir, find_func=find_func)
